@@ -24,8 +24,8 @@ import screeninfo
 from toolium.config_driver import ConfigDriver
 from toolium.config_parser import ExtendedConfigParser
 from toolium.driver_wrappers_pool import DriverWrappersPool
-from toolium.utils import Utils
-from toolium.path_utils import get_valid_filename
+from toolium.utils.driver_utils import Utils
+from toolium.utils.path_utils import get_valid_filename
 
 
 class DriverWrapper(object):
@@ -33,7 +33,7 @@ class DriverWrapper(object):
 
     :type driver: selenium.webdriver.remote.webdriver.WebDriver or appium.webdriver.webdriver.WebDriver
     :type config: toolium.config_parser.ExtendedConfigParser or configparser.ConfigParser
-    :type utils: toolium.utils.Utils
+    :type utils: toolium.utils.driver_utils.Utils
     :type app_strings: dict
     :type session_id: str
     :type remote_node: str
@@ -147,12 +147,9 @@ class DriverWrapper(object):
 
     def configure_visual_baseline(self):
         """Configure baseline directory"""
-        # Get baseline name
+        # Get baseline name and translate config variables
         baseline_name = self.config.get_optional('VisualTests', 'baseline_name', '{Driver_type}')
-        for section in self.config.sections():
-            for option in self.config.options(section):
-                option_value = self.config.get(section, option)
-                baseline_name = baseline_name.replace('{{{0}_{1}}}'.format(section, option), option_value)
+        baseline_name = self.config.translate_config_variables(baseline_name)
 
         # Configure baseline directory if baseline name has changed
         if self.baseline_name != baseline_name:
@@ -290,16 +287,14 @@ class DriverWrapper(object):
 
         :returns: True if test must be executed in an Android mobile
         """
-        driver_name = self.config.get('Driver', 'type').split('-')[0]
-        return driver_name == 'android'
+        return self.utils.get_driver_name() == 'android'
 
     def is_ios_test(self):
         """Check if actual test must be executed in an iOS mobile
 
         :returns: True if test must be executed in an iOS mobile
         """
-        driver_name = self.config.get('Driver', 'type').split('-')[0]
-        return driver_name in ('ios', 'iphone')
+        return self.utils.get_driver_name() in ('ios', 'iphone')
 
     def is_mobile_test(self):
         """Check if actual test must be executed in a mobile
